.. _refpix_step:

==========================
Reference Pixel Correction
==========================

.. toctree::
   :maxdepth: 2

   description.rst
   arguments.rst
   reference_files.rst

.. automodapi:: jwst.refpix
